@@ -3,7 +3,7 @@ use clap::{AppSettings, Parser, Subcommand};
 #[derive(Parser, Debug, PartialEq)]
 #[clap(name = "lic")]
 #[clap(author = "Nyakku Shigure <sigure.qaq@gmail.com>")]
-#[clap(version = "0.1.1")]
+#[clap(version = "0.2.0")]
 #[clap(about = "A SPDX license generator.")]
 #[clap(global_setting(AppSettings::AllowNegativeNumbers))]
 pub struct Cli {
@@ -14,6 +14,7 @@ pub struct Cli {
 #[derive(Subcommand, Debug, PartialEq)]
 pub enum Commands {
     New(OptionsNew),
+    Auto(OptionsAuto),
 }
 
 #[derive(Parser, Debug, PartialEq)]
@@ -24,6 +25,15 @@ pub struct OptionsNew {
     pub width: Option<usize>,
 }
 
+#[derive(Parser, Debug, PartialEq)]
+pub struct OptionsAuto {
+    #[clap(short, long)]
+    pub width: Option<usize>,
+
+    #[clap(short, long)]
+    pub force: bool,
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -39,4 +49,16 @@ mod tests {
             })
         );
     }
+
+    #[test]
+    fn test_auto() {
+        let cli = Cli::parse_from(&["lic", "auto", "-w", "80"]);
+        assert_eq!(
+            cli.command,
+            Commands::Auto(OptionsAuto {
+                width: Some(80),
+                force: false
+            })
+        );
+    }
 }
